Learn R Programming

econet (version 1.0.0.1)

G_alumni_111: Column-normalized adjacency matrix representing the alumni network of the 111th U.S. Congress.

Description

Column-normalized adjacency matrix representing the alumni network of the 111th U.S. Congress.

Usage

data("G_alumni_111")

Arguments

Format

an object of class Matrix with 426 rows and 426 columns

References

Battaglini M., V. Leone Sciabolazza, E. Patacchini (2018), "Effectiveness of Connected Legislators", Mimeo.